@@ -31,7 +31,7 @@
 #define CONF_RENDERING_USE_OWN_FONTS "/apps/epiphany/web/use_own_fonts"
 #define CONF_USER_CSS_ENABLED "/apps/epiphany/web/user_css_enabled"
 #define CONF_SECURITY_ALLOW_POPUPS "/apps/epiphany/web/allow_popups"
-#define CONF_SECURITY_JAVA_ENABLED "/apps/epiphany/web/java_enabled"
+#define CONF_SECURITY_PLUGINS_ENABLED "/apps/epiphany/web/plugins_enabled"
 #define CONF_SECURITY_JAVASCRIPT_ENABLED "/apps/epiphany/web/javascript_enabled"
 #define CONF_SECURITY_COOKIES_ACCEPT "/apps/epiphany/web/cookie_accept"
 #define CONF_LANGUAGE_AUTODETECT_ENCODING "/apps/epiphany/web/autodetect_encoding"
@@ -72,9 +72,11 @@
 
 G_BEGIN_DECLS
 
-void ephy_embed_prefs_init         (void);
-void ephy_embed_prefs_shutdown     (void);
-void ephy_embed_prefs_add_embed    (EphyEmbed *embed);
+void ephy_embed_prefs_init                  (void);
+void ephy_embed_prefs_shutdown              (void);
+void ephy_embed_prefs_add_embed             (EphyEmbed     *embed);
+void ephy_embed_prefs_set_cookie_jar_policy (SoupCookieJar *jar,
+                                             const char    *gconf_policy);
 
 G_END_DECLS
 
