@@ -20,7 +20,6 @@
 #include "config.h"
 
 #include "ephy-gui.h"
-#include "eel-gconf-extensions.h"
 #include "ephy-stock-icons.h"
 #include "ephy-debug.h"
 
@@ -69,16 +68,18 @@ ephy_gui_menu_position_tree_selection (GtkMenu   *menu,
 	GtkTreeView *tree_view = GTK_TREE_VIEW (user_data);
 	GtkWidget *widget = GTK_WIDGET (user_data);
 	GtkRequisition req;
+	GtkAllocation allocation;
 	GdkRectangle visible;
 
 	gtk_widget_size_request (GTK_WIDGET (menu), &req);
-	gdk_window_get_origin (widget->window, x, y);
+	gdk_window_get_origin (gtk_widget_get_window (widget), x, y);
+	gtk_widget_get_allocation (widget, &allocation);
 
-	*x += (widget->allocation.width - req.width) / 2;
+	*x += (allocation.width - req.width) / 2;
 
 	/* Add on height for the treeview title */
 	gtk_tree_view_get_visible_rect (tree_view, &visible);
-	*y += widget->allocation.height - visible.height;
+	*y += allocation.height - visible.height;
 
 	selection = gtk_tree_view_get_selection (tree_view);
 	selected_rows = gtk_tree_selection_get_selected_rows (selection, &model);
@@ -121,7 +122,9 @@ ephy_gui_menu_position_under_widget (GtkMenu   *menu,
 	GtkWidget *container;
 	GtkRequisition req;
 	GtkRequisition menu_req;
+	GtkAllocation allocation;
 	GdkRectangle monitor;
+	GdkWindow *window;
 	int monitor_num;
 	GdkScreen *screen;
   
@@ -134,29 +137,31 @@ ephy_gui_menu_position_under_widget (GtkMenu   *menu,
 	gtk_widget_size_request (GTK_WIDGET (menu), &menu_req);
 
 	screen = gtk_widget_get_screen (GTK_WIDGET (menu));
-	monitor_num = gdk_screen_get_monitor_at_window (screen, widget->window);
+	window = gtk_widget_get_window (widget);
+	monitor_num = gdk_screen_get_monitor_at_window (screen, window);
 	if (monitor_num < 0)
 		monitor_num = 0;
 	gdk_screen_get_monitor_geometry (screen, monitor_num, &monitor);
 
-	gdk_window_get_origin (widget->window, x, y);
-	if (GTK_WIDGET_NO_WINDOW (widget))
+	gtk_widget_get_allocation (widget, &allocation);
+	gdk_window_get_origin (window, x, y);
+	if (!gtk_widget_get_has_window (widget))
 	{
-		*x += widget->allocation.x;
-		*y += widget->allocation.y;
+		*x += allocation.x;
+		*y += allocation.y;
 	}
 
 	if (gtk_widget_get_direction (container) == GTK_TEXT_DIR_LTR) 
-		*x += widget->allocation.width - req.width;
+		*x += allocation.width - req.width;
 	else 
 		*x += req.width - menu_req.width;
 
-	if ((*y + widget->allocation.height + menu_req.height) <= monitor.y + monitor.height)
-		*y += widget->allocation.height;
+	if ((*y + allocation.height + menu_req.height) <= monitor.y + monitor.height)
+		*y += allocation.height;
 	else if ((*y - menu_req.height) >= monitor.y)
 		*y -= menu_req.height;
-	else if (monitor.y + monitor.height - (*y + widget->allocation.height) > *y)
-		*y += widget->allocation.height;
+	else if (monitor.y + monitor.height - (*y + allocation.height) > *y)
+		*y += allocation.height;
 	else
 		*y -= menu_req.height;
 
@@ -186,6 +191,8 @@ ephy_gui_menu_position_on_toolbar (GtkMenu   *menu,
 	GtkToolbar *toolbar;
 	GtkRequisition req;
 	GtkRequisition menu_req;
+	GtkAllocation allocation;
+	GdkWindow *window;
 	GdkRectangle monitor;
 	int monitor_num;
 	GdkScreen *screen;
@@ -199,44 +206,46 @@ ephy_gui_menu_position_on_toolbar (GtkMenu   *menu,
 	gtk_widget_size_request (GTK_WIDGET (menu), &menu_req);
 
 	screen = gtk_widget_get_screen (GTK_WIDGET (menu));
-	monitor_num = gdk_screen_get_monitor_at_window (screen, widget->window);
+	window = gtk_widget_get_window (widget);
+	monitor_num = gdk_screen_get_monitor_at_window (screen, window);
 	if (monitor_num < 0)
 		monitor_num = 0;
 	gdk_screen_get_monitor_geometry (screen, monitor_num, &monitor);
 
-	gdk_window_get_origin (widget->window, x, y);
-	if (GTK_WIDGET_NO_WINDOW (widget))
+	gtk_widget_get_allocation (widget, &allocation);
+	gdk_window_get_origin (window, x, y);
+	if (!gtk_widget_get_has_window (widget))
 	{
-		*x += widget->allocation.x;
-		*y += widget->allocation.y;
+		*x += allocation.x;
+		*y += allocation.y;
 	}
 
-	if (toolbar->orientation == GTK_ORIENTATION_HORIZONTAL)
+	if (gtk_orientable_get_orientation (GTK_ORIENTABLE (toolbar)) == GTK_ORIENTATION_HORIZONTAL)
 	{
 		if (gtk_widget_get_direction (GTK_WIDGET (toolbar)) == GTK_TEXT_DIR_LTR) 
-			*x += widget->allocation.width - req.width;
+			*x += allocation.width - req.width;
 		else 
 			*x += req.width - menu_req.width;
 
-		if ((*y + widget->allocation.height + menu_req.height) <= monitor.y + monitor.height)
-			*y += widget->allocation.height;
+		if ((*y + allocation.height + menu_req.height) <= monitor.y + monitor.height)
+			*y += allocation.height;
 		else if ((*y - menu_req.height) >= monitor.y)
 			*y -= menu_req.height;
-		else if (monitor.y + monitor.height - (*y + widget->allocation.height) > *y)
-			*y += widget->allocation.height;
+		else if (monitor.y + monitor.height - (*y + allocation.height) > *y)
+			*y += allocation.height;
 		else
 			*y -= menu_req.height;
 	}
 	else 
 	{
 		if (gtk_widget_get_direction (GTK_WIDGET (toolbar)) == GTK_TEXT_DIR_LTR) 
-			*x += widget->allocation.width;
+			*x += allocation.width;
 		else 
 			*x -= menu_req.width;
 
 		if (*y + menu_req.height > monitor.y + monitor.height &&
-		    *y + widget->allocation.height - monitor.y > monitor.y + monitor.height - *y)
-			*y += widget->allocation.height - menu_req.height;
+		    *y + allocation.height - monitor.y > monitor.y + monitor.height - *y)
+			*y += allocation.height - menu_req.height;
 	}
 
 	*push_in = FALSE;
@@ -247,7 +256,7 @@ ephy_gui_ensure_window_group (GtkWindow *window)
 {
 	GtkWindowGroup *group;
 
-	group = window->group;
+	group = gtk_window_get_group (window);
 	if (group == NULL)
 	{
 		group = gtk_window_group_new ();
@@ -345,68 +354,37 @@ ephy_gui_check_location_writable (GtkWidget *parent,
 	return TRUE;
 }
 
-static gboolean
-open_url (GtkWindow *parent,
-          const char *uri,
-          guint32 user_time,
-          GError **error)
-{
-  GdkScreen *screen;
-
-  if (parent)
-    screen = gtk_widget_get_screen (GTK_WIDGET (parent));
-  else
-    screen = gdk_screen_get_default ();
-
-  return gtk_show_uri (screen, uri, user_time, error);
-}
-
+/**
+ * ephy_gui_help:
+ * @parent: the parent window where help is being called
+ * @section: help section to open or %NULL
+ *
+ * Displays Epiphany's help, opening the section indicated by @section.
+ *
+ * Note that @parent is used to know the #GdkScreen where to open the help
+ * window.
+ **/
 void
-ephy_gui_help (GtkWindow *parent,
-	       const char *file_name,
-               const char *link_id)
+ephy_gui_help (GtkWidget *parent,
+	       const char *section)
 {
-        GError *error = NULL;
-        const char *lang;
-        char *uri = NULL, *url;
-        guint i;
+	GError *error = NULL;
+	GdkScreen *screen;
+	char *url;
 
-        const char * const * langs = g_get_language_names ();
-        for (i = 0; langs[i]; i++) {
-                lang = langs[i];
-                if (strchr (lang, '.'))
-                        continue;
+	if (section)
+		url = g_strdup_printf ("ghelp:epiphany?%s", section);
+	else
+		url = g_strdup ("ghelp:epiphany");
 
-                uri = g_build_filename (DATADIR,
-                                        "gnome", "help", PACKAGE,
-                                        lang,
-                                        file_name,
-                                        NULL);
-                                                    
-                if (g_file_test (uri, G_FILE_TEST_EXISTS))
-                        break;
+	screen = gtk_widget_get_screen (parent);
+	gtk_show_uri (screen, url, gtk_get_current_event_time (), &error);
 
-                g_free (uri);
-                uri = NULL;
-        }
-
-        if (!uri)
-                return;
-
-        if (link_id)
-        {
-                url = g_strdup_printf ("ghelp://%s?%s", uri, link_id);
-        }
-        else
-        {
-                url = g_strdup_printf ("ghelp://%s", uri);
-        }
-
-        if (!open_url (parent, url, gtk_get_current_event_time (), &error))
-        {
+	if (error != NULL)
+	{
 		GtkWidget *dialog;
 
-		dialog = gtk_message_dialog_new (parent,
+		dialog = gtk_message_dialog_new (GTK_WINDOW (parent),
 						 GTK_DIALOG_DESTROY_WITH_PARENT,
 						 GTK_MESSAGE_ERROR,
 						 GTK_BUTTONS_OK,
@@ -417,9 +395,9 @@ ephy_gui_help (GtkWindow *parent,
 		g_signal_connect (dialog, "response",
 				  G_CALLBACK (gtk_widget_destroy), NULL);
 		gtk_widget_show (dialog);
-        }
+	}
 
-        g_free (url);
+	g_free (url);
 }
 
 void
@@ -498,7 +476,7 @@ ephy_gui_window_update_user_time (GtkWidget *window,
 	if (user_time != 0)
 	{
 		gtk_widget_realize (window);
-		gdk_x11_window_set_user_time (window->window,
+		gdk_x11_window_set_user_time (gtk_widget_get_window (window),
 					      user_time);
 	}
 
@@ -512,7 +490,7 @@ ephy_gui_message_dialog_get_content_box (GtkWidget *dialog)
 	GList *children;
 
 	/* Get the hbox which is the first child of the main vbox */
-	children = gtk_container_get_children (GTK_CONTAINER (GTK_DIALOG (dialog)->vbox));
+	children = gtk_container_get_children (GTK_CONTAINER (gtk_dialog_get_content_area (GTK_DIALOG (dialog))));
 	g_return_val_if_fail (children != NULL, NULL);
 
 	container = GTK_WIDGET (children->data);
@@ -527,45 +505,3 @@ ephy_gui_message_dialog_get_content_box (GtkWidget *dialog)
 
 	return container;
 }
-
-/* Until bug #345349 is fixed */
-void
-ephy_gui_message_dialog_set_wrap_mode (GtkMessageDialog *dialog,
-				       PangoWrapMode wrap_mode)
-{
-	GtkContainer *container;
-	GList *children, *l;
-
-	container = GTK_CONTAINER (dialog->label->parent);
-	g_return_if_fail (GTK_IS_CONTAINER (container));
-
-	children = gtk_container_get_children (container);
-	for (l = children; l != NULL; l = l->next)
-	{
-		GtkWidget *child = l->data;
-
-		if (GTK_IS_LABEL (child))
-		{
-			g_print ("Setting wrap mode on label %p\n", child);
-			gtk_label_set_line_wrap_mode (GTK_LABEL (child),
-						      wrap_mode);
-		}
-	}
-}
-
-static void
-checkbutton_toggled_cb (GtkToggleButton *button,
-			const char *pref)
-{
-	eel_gconf_set_boolean (pref, gtk_toggle_button_get_active (button));
-}
-
-void
-ephy_gui_connect_checkbutton_to_gconf (GtkWidget *widget,
-				       const char *pref)
-{
-	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (widget),
-				      eel_gconf_get_boolean (pref));
-	g_signal_connect (widget, "toggled",
-			  G_CALLBACK (checkbutton_toggled_cb), (gpointer) pref);
-}
