@@ -183,7 +183,7 @@ pdm_dialog_show_help (PdmDialog *pd)
 	id = gtk_notebook_get_current_page (GTK_NOTEBOOK (notebook));
 	g_return_if_fail (id == 0 || id == 1);
 
-	ephy_gui_help (GTK_WINDOW (window), "epiphany", help_preferences[id]);
+	ephy_gui_help (window, help_preferences[id]);
 }
 
 typedef struct
@@ -255,8 +255,7 @@ clear_all_dialog_response_cb (GtkDialog *dialog,
 	if (response == GTK_RESPONSE_HELP)
 	{
 		/* Show help and return early */
-
-		ephy_gui_help (GTK_WINDOW (dialog), "epiphany", "clearing-personal-data");
+		ephy_gui_help (GTK_WIDGET (dialog), "clearing-personal-data");
 		return;
 	}
 
@@ -352,13 +351,27 @@ clear_all_dialog_checkbutton_toggled_cb (GtkToggleButton *toggle,
 					   data->num_checked != 0);
 }
 
+static GtkWidget*
+_gtk_message_dialog_get_content_area (GtkMessageDialog *dialog)
+{
+	GtkWidget *image, *parent, *box;
+	GList *children;
+
+	image = gtk_message_dialog_get_image (dialog);
+	parent = gtk_widget_get_parent (image);
+	children = gtk_container_get_children (GTK_CONTAINER (parent));
+	box = GTK_WIDGET (children->next->data);
+	g_list_free (children);
+	return box;
+}
+
 void
 pdm_dialog_show_clear_all_dialog (EphyDialog *edialog,
 				  GtkWidget *parent,
 				  PdmClearAllDialogFlags flags)
 {
 	GtkWidget *dialog, *vbox;
-	GtkWidget *check, *label;
+	GtkWidget *check, *label, *content_area;
 	PdmClearAllDialogButtons *checkbuttons;
 	GtkWidget *button, *icon;
 
@@ -394,11 +407,17 @@ pdm_dialog_show_clear_all_dialog (EphyDialog *edialog,
 
 	gtk_dialog_set_default_response (GTK_DIALOG (dialog),
 					 GTK_RESPONSE_CANCEL);
+#if 0
 	gtk_label_set_selectable (GTK_LABEL (GTK_MESSAGE_DIALOG (dialog)->label),
 				  FALSE);
+#endif
 
 	vbox = gtk_vbox_new (FALSE, 6);
-	gtk_box_pack_start (GTK_BOX (GTK_MESSAGE_DIALOG (dialog)->label->parent),
+	/* This is extremely evil, but at least we'll compile with
+	 * GSEAL enabled until #328069 is resolved. If it's WONTFIXED
+	 * we'll just do this from scratch with a normal GtkDialog */
+	content_area = _gtk_message_dialog_get_content_area (GTK_MESSAGE_DIALOG (dialog));
+	gtk_box_pack_start (GTK_BOX (content_area),
 			    vbox, FALSE, FALSE, 0);
 
 	checkbuttons = g_slice_new0 (PdmClearAllDialogButtons);
@@ -1489,7 +1508,7 @@ pdm_dialog_password_remove (PdmActionInfo *info,
 
 static void
 sync_notebook_tab (GtkWidget *notebook,
-		   GtkNotebookPage *page,
+		   GtkWidget *page,
 		   int page_num,
 		   PdmDialog *dialog)
 {
